@@ -8,7 +8,7 @@ use base qw(Exporter DynaLoader);
 use Carp;
 use Try::Tiny;
 
-our $VERSION = '0.09_02';
+our $VERSION = '0.09_03';
 
 sub dl_load_flags { 1 } # Make PerlXLib.c functions available to other XS modules
 
@@ -179,8 +179,8 @@ X11::Xlib - Low-level access to the X11 library
   
   use X11::Xlib;
   my $display= X11::Xlib->new($conn_string);  # shortcut for X11::Xlib::Display->new
-  my $window= $display->new_window({ x => 0, y => 0, width => 50, height => 50);
-  $window->show();
+  $display->fake_motion(undef, 50, 50)
+  $display->flush;
 
 =head1 DESCRIPTION
 
@@ -198,8 +198,6 @@ on that, you get a more friendly wrapper around Xlib that helps you manage
 resource lifespan, wraps XIDs with perl objects, and does some sanity checking
 on the state of the library when you call methods.
 
-=cut
-
 =head1 ATTRIBUTES
 
 The X11::Xlib connection is a hashref with a few attributes and methods
@@ -207,7 +205,7 @@ independent of Xlib.
 
 =head2 autoclose
 
-Boolean flag that determines whether the destructor will call XCloseDisplay.
+Boolean flag that determines whether the destructor will call L</XCloseDisplay>.
 Defaults to true for connections returned by L</XOpenDisplay>.
 
 =head1 FUNCTIONS
@@ -237,7 +235,7 @@ would have to perform all cleanup with your stack tied up through Xlib, but
 this library cheats by using croak (C<longjmp>) to escape the callback and let
 you wrap up your script in a normal manner.  B<However>, after a fatal
 error Xlib's internal state could be dammaged, so it is unsafe to make any more
-Xlib calls.  The library tries to help assert this by invalidating all the
+Xlib calls.  This library tries to help enforce that by invalidating all the
 connection objects.
 
 If you really need your program to keep running your best bet is to state-dump
@@ -771,8 +769,6 @@ Xlib docs are fun.  No mention of what "PF" might be.
 
 True for vendor-private key codes.
 
-=cut
-
 =head1 STRUCTURES
 
 Xlib has a lot of C B<struct>s.  Most of them do not have much "depth"
@@ -882,7 +878,7 @@ through the GTK API and perl objects.
 
 =head1 TODO
 
-This module still only covers a small fraction of the Xlib API.
+This module still only covers a fraction of the Xlib API.
 Patches are welcome :)
 
 =head1 AUTHOR
